@@ -19,9 +19,7 @@ class Authenticator:
         "SCOPE": "psn:clientapp psn:mobile.v1",
         "REDIRECT_URI": "com.playstation.PlayStationApp://redirect",
     }
-    __AUTH_HEADER = {
-        "Authorization": "Basic YWM4ZDE2MWEtZDk2Ni00NzI4LWIwZWEtZmZlYzIyZjY5ZWRjOkRFaXhFcVhYQ2RYZHdqMHY="
-    }
+    __AUTH_HEADER = {"Authorization": "Basic YWM4ZDE2MWEtZDk2Ni00NzI4LWIwZWEtZmZlYzIyZjY5ZWRjOkRFaXhFcVhYQ2RYZHdqMHY="}
 
     def __init__(self, npsso_cookie: str):
         """Represents a single authentication to PSN API.
@@ -58,13 +56,9 @@ class Authenticator:
             data=data,
         )
         self._auth_properties = response.json()
-        self._auth_properties["access_token_expires_at"] = (
-            self._auth_properties["expires_in"] + time.time()
-        )
+        self._auth_properties["access_token_expires_at"] = self._auth_properties["expires_in"] + time.time()
         if self._auth_properties["refresh_token_expires_in"] <= 60 * 60 * 24 * 3:
-            self._authenticator_logger.warning(
-                "Warning: Your refresh token is going to expire in less than 3 days. Please renew you npsso token!"
-            )
+            self._authenticator_logger.warning("Warning: Your refresh token is going to expire in less than 3 days. Please renew you npsso token!")
         return self._auth_properties["access_token"]
 
     def oauth_token(self, code: str) -> None:
@@ -88,20 +82,15 @@ class Authenticator:
             data=data,
         )
         self._auth_properties = response.json()
-        self._auth_properties["access_token_expires_at"] = (
-            self._auth_properties["expires_in"] + time.time()
-        )
+        self._auth_properties["access_token_expires_at"] = self._auth_properties["expires_in"] + time.time()
         if self._auth_properties["refresh_token_expires_in"] <= 60 * 60 * 24 * 3:
-            self._authenticator_logger.warning(
-                "Warning: Your refresh token is going to expire in less than 3 days. Please renew you npsso token!"
-            )
+            self._authenticator_logger.warning("Warning: Your refresh token is going to expire in less than 3 days. Please renew you npsso token!")
 
     def _authenticate(self) -> None:
         """Authenticate using the npsso code provided in the constructor.
 
-        Obtains the access code and the refresh code. Access code lasts about 1 hour.
-        While the refresh code lasts about 2 months. After 2 months a new npsso code is
-        needed.
+        Obtains the access code and the refresh code. Access code lasts about 1 hour. While the refresh code lasts about 2 months. After 2 months a new npsso
+        code is needed.
 
         :raises: ``PSNAWPAuthenticationError`` If authentication is not successful.
 
@@ -126,11 +115,7 @@ class Authenticator:
         parsed_query = parse_qs(parsed_url.query)
         if "error" in parsed_query.keys():
             if "4165" in parsed_query["error_code"]:
-                raise psnawp_exceptions.PSNAWPAuthenticationError(
-                    "Your npsso code has expired or is incorrect. Please generate a new code!"
-                )
+                raise psnawp_exceptions.PSNAWPAuthenticationError("Your npsso code has expired or is incorrect. Please generate a new code!")
             else:
-                raise psnawp_exceptions.PSNAWPAuthenticationError(
-                    "Something went wrong while authenticating"
-                )
+                raise psnawp_exceptions.PSNAWPAuthenticationError("Something went wrong while authenticating")
         self.oauth_token(parsed_query["code"][0])
