@@ -1,8 +1,10 @@
 from __future__ import annotations
 
 import json
+from typing import Any
 
-from psnawp_api.utils.endpoints import BASE_PATH, API_PATH
+from psnawp_api.core.psnawp_exceptions import PSNAWPNotFound
+from psnawp_api.utils.endpoints import BASE_PATH
 from psnawp_api.utils.request_builder import RequestBuilder
 
 
@@ -14,14 +16,13 @@ class Search:
 
             This class is intended to be interfaced with through PSNAWP.
 
-        :param request_builder: The instance of RequestBuilder. Used to make
-            HTTPRequests.
+        :param request_builder: The instance of RequestBuilder. Used to make HTTPRequests.
         :type request_builder: RequestBuilder
 
         """
         self._request_builder = request_builder
 
-    def universal_search(self, search_query: str, limit: int = 20):
+    def universal_search(self, search_query: str, limit: int = 20) -> dict[str, Any]:
         """Searches the Playstation Website. Note: It does not work as of now and the endpoints returns whole html page.
 
         .. note::
@@ -33,8 +34,7 @@ class Search:
         :param limit: Limit of number of results
         :type limit: int
 
-        :returns: A dict containing info similar to what is shown below (Not all values
-            are shown because of space limitations):
+        :returns: A dict containing info similar to what is shown below (Not all values are shown because of space limitations):
         :rtype: dict[str, Any]
 
             .. code-block:: json
@@ -84,66 +84,45 @@ class Search:
             "languageCode": "en",
             "age": 99,
         }
-        response = self._request_builder.post(
-            url=f"{BASE_PATH['universal_search']}", data=json.dumps(data)
-        ).json()
+        response: dict[str, Any] = self._request_builder.post(url=f"{BASE_PATH['universal_search']}", data=json.dumps(data)).json()
         return response
 
-    def get_title_details(self, title_id: str):
-        """get a title details using its code (eg. CUSA05486_00) as source.
+    def get_title_id(self, title_name: str) -> tuple[str, str]:
+        """Gets the title id from title name using universal search endpoint.
 
-        :param title_id: unique id of game.
-        :type title_id: str
+        .. warning::
 
-        :returns: A dict containing info similar to what is shown below (Not all values
-            are shown because of space limitations):
-        :rtype: dict[str, Any]
+            Make sure to use the official full name of the video game otherwise the returned results may not be accurate. For example: GTA V returns the GTA
+            Vice City since the Vice City shows up above GTA V. However, Grand Theft Auto V returns the correct results.
 
-            .. code-block:: json
+        :param title_name: Video Game title name
+        :type title_name: str
 
-                [
-                    {
-                        "id": 201930,
-                        "name": "Grand Theft Auto V (PlayStation®5)",
-                        "nameEn": "Grand Theft Auto V (PlayStation®5)",
-                        "publisherName": "Rockstar Games",
-                        "media": {
-                        },
-                        "descriptions": [],
-                        "categorizedProducts": [],
-                        "titleIds": [],
-                        "country": "US",
-                        "language": "en",
-                        "type": "GAME",
-                        "localizedName": {},
-                        "localizedDescriptions": {},
-                        "localizedPublisherName": {},
-                        "defaultProduct": {},
-                        "genres": [],
-                        "localizedGenres": [],
-                        "subGenres": [],
-                        "localizedSubGenres": [],
-                        "minimumAge": 17,
-                        "releaseDate": {},
-                        "isRecommendableOnStore": true,
-                        "isSearchableOnStore": true,
-                        "storeFronts": [],
-                        "supportedStoreFronts": [],
-                        "marketingStories": [],
-                        "compatibilityNotices": [],
-                        "localizedMedia": {},
-                        "revisionIds": {},
-                        "contentRating": {}
-                    }
-                ]
+        :returns: A tuple containing English Title Name and Title ID
+        :rtype: tuple[str, str]
 
         """
-
-        param = {"age": 99, "country": "US", "language": "en-US"}
-
-        response = self._request_builder.get(
-            url=f"{BASE_PATH['game_titles']}{API_PATH['title_concept'].format(title_id=title_id)}",
-            params=param,
-        ).json()
-
-        return response
+        data = {
+            "searchTerm": title_name,
+            "domainRequests": [
+                {
+                    "domain": "ConceptGameMobileApp",
+                    "pagination": {"cursor": "", "pageSize": 1},
+                    "featureFlags": {"isSpartacusEnabled": True},
+                }
+            ],
+            "countryCode": "us",
+            "languageCode": "en",
+            "age": 99,
+        }
+        response: dict[str, Any] = self._request_builder.post(url=f"{BASE_PATH['universal_search']}", data=json.dumps(data)).json()
+        result = response["domainResponses"][0]["results"]
+        if len(result) >= 1:
+            t: tuple[str, str] = (
+                result[0]["conceptProductMetadata"]["nameEn"],
+                result[0]["conceptProductMetadata"]["titleId"],
+            )
+            title_name, title_id = t
+        else:
+            raise PSNAWPNotFound("Could not find Game by the that title name.")
+        return title_name, title_id
