@@ -7,11 +7,14 @@ BASE_PATH = {
     "group_messaging": "https://us-gmsg.np.community.playstation.net/groupMessaging/v1",
     "universal_search": "https://m.np.playstation.com/api/search/v1/universalSearch",
     "game_titles": "https://m.np.playstation.com/api/catalog/v2/titles",
+    "trophies": "https://m.np.playstation.com/api/trophy/v1",
 }
 
 API_PATH = {
+    # Auth Endpoints
     "oauth_code": "/authz/v3/oauth/authorize",
     "access_token": "/authz/v3/oauth/token",
+    # Client/User Endpoint
     "my_account": "/v1/devices/accounts/me",
     "profiles": "/{account_id}/profiles",
     "legacy_profile": "/{online_id}/profile2",
@@ -20,6 +23,7 @@ API_PATH = {
     "available_to_play": "/me/friends/subscribing/availableToPlay",
     "blocked_users": "/me/blocks",
     "basic_presences": "/basicPresences",
+    # Group Endpoints
     "my_groups": "/members/me/groups",
     "group_settings": "/groups/{group_id}",
     "create_group": "/groups",
@@ -27,5 +31,14 @@ API_PATH = {
     "send_group_message": "/groups/{group_id}/threads/{group_id}/messages",
     "conversation": "/members/me/groups/{group_id}/threads/{group_id}/messages",
     "leave_group": "/groups/{group_id}/members/me",
+    # Game Title Details
     "title_concept": "/{title_id}/concepts",
+    # Trophy Endpoints
+    "trophy_titles": "/users/{account_id}/trophyTitles",
+    "trophies_for_title": "/npCommunicationIds/{np_communication_id}/trophyGroups/{trophy_group_id}/trophies",
+    "trophies_earned_for_title": "/users/{account_id}/npCommunicationIds/{np_communication_id}/trophyGroups/{trophy_group_id}/trophies",
+    "trophy_summary": "/users/{account_id}/trophySummary",
+    "title_trophy_group": "/npCommunicationIds/{np_communication_id}/trophyGroups",
+    "user_title_trophy_group": "/users/{account_id}/npCommunicationIds/{np_communication_id}/trophyGroups",
+    "trophy_titles_for_title": "/users/{account_id}/titles/trophyTitles",
 }
